@@ -12,7 +12,7 @@ __author__ = "Ali Onur Uyar"
 __copyright__ = "Copyright 2011, Ali Onur Uyar"
 __credits__ = []
 __license__ = "GPL"
-__version__ = "0.9.15"
+__version__ = "0.9.19"
 __maintainer__ = "Ali Onur Uyar"
 __email__ = "aouyar at gmail.com"
 __status__ = "Development"
@@ -325,4 +325,18 @@ class PgInfo:
                 info_dict[row[0]] = dict(zip(cols[1:], row[1:]))
         else:
             return None
-        return info_dict
\ No newline at end of file
+        return info_dict
+    
+    def getSlaveConflictStats(self):
+        if self.checkVersion('9.1'):
+            headers = ('datname', 'confl_tablespace', 'confl_lock', 'confl_snapshot', 
+                       'confl_bufferpin', 'confl_deadlock')
+            cur = self._conn.cursor()
+            cur.execute("SELECT %s FROM pg_stat_database_conflicts;" 
+                    % ",".join(headers))
+            rows = cur.fetchall()
+            dbstats = self._createStatsDict(headers, rows)
+            totals = self._createTotalsDict(headers, rows)
+            return {'databases': dbstats, 'totals': totals}
+        else:
+            return None
\ No newline at end of file
